/*
 * This file is part of vospace-ui
 * Copyright (C) 2021 Istituto Nazionale di Astrofisica
 * SPDX-License-Identifier: GPL-3.0-or-later
 */
package it.inaf.ia2.vospace.ui.service;

import it.inaf.ia2.aa.data.User;
import net.ivoa.xml.vospace.v2.Node;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

public class MoveNodeModalHtmlGenerator extends NodesHtmlGenerator {

    private final String nodeNodeMovePath;

    public MoveNodeModalHtmlGenerator(Node node, String nodeNodeMovePath, User user, String authority) {
        super(node, user, authority);
        this.nodeNodeMovePath = nodeNodeMovePath;
    }

    @Override
    protected Element createContainerElement(Document html) {
        Element container = html.body().appendElement("div");
        container.attr("id", "move-nodes");
        container.attr("class", "list-group");
        return container;
    }

    @Override
    protected void addChild(Node child, Element containerElement) {
        NodeInfo nodeInfo = new NodeInfo(child, user, authority);

        if (!nodeInfo.isFolder() || nodeInfo.getPath().equals(nodeNodeMovePath)) {
            return;
        }

        Element row = containerElement.appendElement("div");
        row.addClass("list-group-item");

        addNodeIcon(nodeInfo, row);
        addLink(nodeInfo, row);
    }

    private void addLink(NodeInfo nodeInfo, Element cell) {
        Element link = cell.appendElement("a");
        link.attr("href", "#");
        link.attr("onclick", "openNodeInMoveModal(event, " + makeJsArg(nodeInfo.getPath()) + ")");
        link.text(nodeInfo.getName());
    }
}
