/*
 * This file is part of vospace-ui
 * Copyright (C) 2021 Istituto Nazionale di Astrofisica
 * SPDX-License-Identifier: GPL-3.0-or-later
 */
package it.inaf.ia2.vospace.ui.service;

import it.inaf.ia2.aa.data.User;
import net.ivoa.xml.vospace.v2.ContainerNode;
import net.ivoa.xml.vospace.v2.Node;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

public abstract class NodesHtmlGenerator {

    private final Node parentNode;

    protected final User user;
    protected final String authority;

    private Element containerElement;

    protected NodesHtmlGenerator(Node node, User user, String authority) {
        this.parentNode = node;
        this.user = user;
        this.authority = authority;
    }

    public String generateNodes() {

        Document html = Jsoup.parse("<html></html>");

        containerElement = createContainerElement(html);
        
        if (parentNode instanceof ContainerNode) {
            ContainerNode folder = (ContainerNode) parentNode;
            for (Node child : folder.getNodes()) {
                addChild(child, containerElement);
            }
        }

        return containerElement.toString();
    }

    protected abstract Element createContainerElement(Document doc);
    
    protected abstract void addChild(Node child, Element containerElement);

    protected String makeJsArg(String arg) {
        return "'" + arg.replace("\\", "\\\\").replace("'", "\\'") + "'";
    }

    protected void addNodeIcon(NodeInfo nodeInfo, Element parentElement) {

        if (nodeInfo.isBusy()) {
            Element loadingWrapper = parentElement.appendElement("span");
            loadingWrapper.addClass("node-busy");
            Element spinner = loadingWrapper.appendElement("span");
            spinner.attr("role", "status");
            spinner.addClass("spinner-border");
            Element srEl = spinner.appendElement("span");
            srEl.addClass("sr-only");
            srEl.text("Loading...");
        }

        Element icon = parentElement.appendElement("span");
        icon.addClass("icon");

        if (nodeInfo.isFolder()) {
            if (nodeInfo.isAsyncTrans()) {
                icon.addClass("folder-x-icon");
            } else {
                icon.addClass("folder-icon");
            }
        } else {
            if (nodeInfo.isAsyncTrans()) {
                icon.addClass("file-x-icon");
            } else {
                icon.addClass("file-icon");
            }
        }

        parentElement.append("&nbsp;");
    }
}
