/*
 * This file is part of vospace-ui
 * Copyright (C) 2021 Istituto Nazionale di Astrofisica
 * SPDX-License-Identifier: GPL-3.0-or-later
 */
import root from './data/nodes/root';
import folder1 from './data/nodes/folder1';
import folder2 from './data/nodes/folder2';
import job from './data/job';
import jobs from './data/jobs';
import user from './data/user';
import sharing from './data/sharing';

import store from '../../store';

const fetch = (mockData, showLoading = true, time = 500) => {
  return new Promise((resolve) => {
    if (showLoading) {
      store.commit('setLoading', true);
    }
    setTimeout(() => {
      resolve(mockData)
      if (showLoading) {
        store.commit('setLoading', false);
      }
    }, time);
  });
};

export default {
  getNode(path) {
    let response;
    switch (path) {
      case '':
        response = root;
        break;
      case 'folder1':
        response = folder1;
        break;
      case 'folder1/folder2':
        response = folder2;
        break;
    }
    return fetch(response);
  },
  startAsyncRecallJob() {
    return fetch(job);
  },
  loadJobs() {
    return fetch(jobs, false);
  },
  getUserInfo() {
    return fetch(user, false);
  },
  createFolder() {
    return fetch({});
  },
  prepareForUpload() {
    return fetch(['http://fileservice/upload']);
  },
  uploadFile() {
    return fetch({});
  },
  deleteNodes() {
    return fetch({});
  },
  keepalive() {
    return fetch({}, false);
  },
  getSharingInfo() {
    return fetch(sharing);
  },
  setNodeGroups() {
    return fetch({});
  }
}
